@@ -857,6 +857,7 @@ void EditProfileDialog::removeKeyBinding()
             _ui->keyBindingList->model()->removeRow(selected.first().row());
     }
 }
+
 void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
 {
     QModelIndexList selected = _ui->keyBindingList->selectionModel()->selectedIndexes();
@@ -870,16 +871,16 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
 
     Q_ASSERT(translator);
 
-    QDialog dialog(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(&dialog);
+    QPointer<QDialog> dialog = new QDialog(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(dialog);
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(buttonBox, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
-    connect(buttonBox, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
+    connect(buttonBox, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
 
     if (isNewTranslator)
-        dialog.setWindowTitle(i18n("New Key Binding List"));
+        dialog->setWindowTitle(i18n("New Key Binding List"));
     else
-        dialog.setWindowTitle(i18n("Edit Key Binding List"));
+        dialog->setWindowTitle(i18n("Edit Key Binding List"));
 
     KeyBindingEditor* editor = new KeyBindingEditor;
 
@@ -892,9 +893,9 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(editor);
     layout->addWidget(buttonBox);
-    dialog.setLayout(layout);
+    dialog->setLayout(layout);
 
-    if (dialog.exec() == QDialog::Accepted) {
+    if (dialog->exec() == QDialog::Accepted) {
         KeyboardTranslator* newTranslator = new KeyboardTranslator(*editor->translator());
 
         if (isNewTranslator)
@@ -911,6 +912,7 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
             updateTempProfileProperty(Profile::KeyBindings, newTranslator->name());
         }
     }
+    delete dialog;
 }
 void EditProfileDialog::newKeyBinding()
 {
@@ -1010,10 +1012,15 @@ void EditProfileDialog::scrollHalfPage()
 }
 void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
 {
-    BooleanOption  options[] = { {
+    BooleanOption  options[] = {
+        {
             _ui->underlineLinksButton , Profile::UnderlineLinksEnabled,
             SLOT(toggleUnderlineLinks(bool))
         },
+        {
+            _ui->underlineFilesButton , Profile::UnderlineFilesEnabled,
+            SLOT(toggleUnderlineFiles(bool))
+        },
         {
             _ui->ctrlRequiredForDragButton, Profile::CtrlRequiredForDrag,
             SLOT(toggleCtrlRequiredForDrag(bool))
@@ -1057,7 +1064,7 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
 
     connect(_ui->tripleClickModeCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated), this, &Konsole::EditProfileDialog::TripleClickModeChanged);
 
-    _ui->openLinksByDirectClickButton->setEnabled(_ui->underlineLinksButton->isChecked());
+    _ui->openLinksByDirectClickButton->setEnabled(_ui->underlineLinksButton->isChecked() || _ui->underlineFilesButton->isChecked());
 
     _ui->enableMouseWheelZoomButton->setChecked(profile->mouseWheelZoomEnabled());
     connect(_ui->enableMouseWheelZoomButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::toggleMouseWheelZoom);
@@ -1065,10 +1072,6 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
 void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
 {
     BooleanOption  options[] = {
-        {
-            _ui->enableUrlHints , Profile::EnableUrlHints ,
-            SLOT(toggleEnableUrlHints(bool))
-        },
         {
             _ui->enableBlinkingTextButton , Profile::BlinkingTextEnabled ,
             SLOT(toggleBlinkingText(bool))
@@ -1089,6 +1092,19 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
     };
     setupCheckBoxes(options , profile);
 
+    // Setup the URL hints modifier checkboxes
+    {
+        int modifiers = profile->property<int>(Profile::UrlHintsModifiers);
+        _ui->urlHintsModifierShift->setChecked(modifiers & Qt::ShiftModifier);
+        _ui->urlHintsModifierCtrl->setChecked(modifiers & Qt::ControlModifier);
+        _ui->urlHintsModifierAlt->setChecked(modifiers & Qt::AltModifier);
+        _ui->urlHintsModifierMeta->setChecked(modifiers & Qt::MetaModifier);
+        connect(_ui->urlHintsModifierShift, &QCheckBox::toggled, this, &EditProfileDialog::updateUrlHintsModifier);
+        connect(_ui->urlHintsModifierCtrl, &QCheckBox::toggled, this, &EditProfileDialog::updateUrlHintsModifier);
+        connect(_ui->urlHintsModifierAlt, &QCheckBox::toggled, this, &EditProfileDialog::updateUrlHintsModifier);
+        connect(_ui->urlHintsModifierMeta, &QCheckBox::toggled, this, &EditProfileDialog::updateUrlHintsModifier);
+    }
+
     const int lineSpacing = profile->lineSpacing();
     _ui->lineSpacingSpinner->setValue(lineSpacing);
 
@@ -1163,7 +1179,16 @@ void EditProfileDialog::toggleBlinkingCursor(bool enable)
 void EditProfileDialog::toggleUnderlineLinks(bool enable)
 {
     updateTempProfileProperty(Profile::UnderlineLinksEnabled, enable);
-    _ui->openLinksByDirectClickButton->setEnabled(enable);
+
+    bool enableClick = _ui->underlineFilesButton->isChecked() || enable;
+    _ui->openLinksByDirectClickButton->setEnabled(enableClick);
+}
+void EditProfileDialog::toggleUnderlineFiles(bool enable)
+{
+    updateTempProfileProperty(Profile::UnderlineFilesEnabled, enable);
+
+    bool enableClick = _ui->underlineLinksButton->isChecked() || enable;
+    _ui->openLinksByDirectClickButton->setEnabled(enableClick);
 }
 void EditProfileDialog::toggleCtrlRequiredForDrag(bool enable)
 {
@@ -1197,9 +1222,14 @@ void EditProfileDialog::TripleClickModeChanged(int newValue)
 {
     updateTempProfileProperty(Profile::TripleClickMode, newValue);
 }
-void EditProfileDialog::toggleEnableUrlHints(bool enable)
+void EditProfileDialog::updateUrlHintsModifier(bool)
 {
-    updateTempProfileProperty(Profile::EnableUrlHints, enable);
+    Qt::KeyboardModifiers modifiers;
+    if (_ui->urlHintsModifierShift->isChecked()) modifiers |= Qt::ShiftModifier;
+    if (_ui->urlHintsModifierCtrl->isChecked())  modifiers |= Qt::ControlModifier;
+    if (_ui->urlHintsModifierAlt->isChecked())   modifiers |= Qt::AltModifier;
+    if (_ui->urlHintsModifierMeta->isChecked())  modifiers |= Qt::MetaModifier;
+    updateTempProfileProperty(Profile::UrlHintsModifiers, int(modifiers));
 }
 void EditProfileDialog::toggleBlinkingText(bool enable)
 {
@@ -1228,7 +1258,7 @@ void EditProfileDialog::showFontDialog()
     bool result;
     if (showAllFonts) {
         currentFont = QFontDialog::getFont(&result, currentFont, this,
-                                       i18n("Select All Font"));
+                                       i18n("Select Any Font"));
     } else {
         currentFont = QFontDialog::getFont(&result, currentFont, this,
                                        i18n("Select Fixed Width Font"),
