@@ -21,17 +21,25 @@
 // Own
 #include "GeneralSettings.h"
 
+#include <KMessageBox>
+
 using namespace Konsole;
 
 GeneralSettings::GeneralSettings(QWidget* aParent) : QWidget(aParent)
 {
     setupUi(this);
 
+    connect(enableAllMessagesButton, &QPushButton::clicked, this, &Konsole::GeneralSettings::slotEnableAllMessages);
+
     this->kcfg_ShowTerminalSizeHint->setVisible(false);
-    this->kcfg_SaveGeometryOnExit->setVisible(false);
 }
 
 GeneralSettings::~GeneralSettings()
 {
 }
 
+void GeneralSettings::slotEnableAllMessages()
+{
+    KMessageBox::enableAllMessages();
+}
+
